@@ -2,15 +2,27 @@
 dcnorm <- function(x, mean = 0, sd = 1, left = -Inf, right = Inf, log = FALSE) {
   input <- data.frame(x = as.numeric(x), mean = as.numeric(mean), sd = as.numeric(sd), 
     left = as.numeric(left), right = as.numeric(right))
-  with(input, .Call("dcnorm", x, mean, sd, left, right, log))
+  rval <- with(input, .Call("cdcnorm", x, mean, sd, left, right, log))
+  if(is.matrix(x)) {
+    rval <- matrix(rval, ncol = ncol(x), nrow = nrow(x))
+    colnames(rval) <- colnames(x)
+    rownames(rval) <- rownames(x)
+  }
+  return(rval)
 }
 
 ## distribution function
-pcnorm <- function(q, mean = 0, sd = 1, lower.tail = TRUE, log.p = FALSE, 
-  left = -Inf, right = Inf) {
+pcnorm <- function(q, mean = 0, sd = 1, left = -Inf, right = Inf, 
+  lower.tail = TRUE, log.p = FALSE) {
   input <- data.frame(q = as.numeric(q), mean = as.numeric(mean), sd = as.numeric(sd), 
     left = as.numeric(left), right = as.numeric(right))
-  with(input, .Call("pcnorm", q, mean, sd, left, right, lower.tail, log.p))
+  rval <- with(input, .Call("cpcnorm", q, mean, sd, left, right, lower.tail, log.p))
+  if(is.matrix(q)) {
+    rval <- matrix(rval, ncol = ncol(q), nrow = nrow(q))
+    colnames(rval) <- colnames(q)
+    rownames(rval) <- rownames(q)
+  }
+  return(rval)
 }
 
 ## random numbers
@@ -20,15 +32,21 @@ rcnorm <- function(n, mean = 0, sd = 1, left = -Inf, right = Inf) {
 }
 
 ## quantiles
-qcnorm <- function(p, mean = 0, sd = 1, lower.tail = TRUE, log.p = FALSE, 
-  left = -Inf, right = Inf) {
+qcnorm <- function(p, mean = 0, sd = 1, left = -Inf, right = Inf, 
+  lower.tail = TRUE, log.p = FALSE) {
   rval <- qnorm(p, lower.tail = lower.tail, log.p = log.p) * sd + mean
-  pmax(pmin(rval, right), left)
+  rval <- pmax(pmin(rval, right), left)
+  if(is.matrix(p)) {
+    rval <- matrix(rval, ncol = ncol(p), nrow = nrow(p))
+    colnames(rval) <- colnames(p)
+    rownames(rval) <- rownames(p)
+  }
+  return(rval)
 }
 
 ## scores
-scnorm <- function(x, mean = 0, sd = 1, which = c("mu", "sigma"), 
-  left = -Inf, right = Inf) {
+scnorm <- function(x, mean = 0, sd = 1, left = -Inf, right = Inf,
+  which = c("mu", "sigma")) {
   input <- data.frame(x = as.numeric(x), mean = as.numeric(mean), sd = as.numeric(sd), 
     left = as.numeric(left), right = as.numeric(right))
   if(!is.character(which))
@@ -50,8 +68,8 @@ scnorm <- function(x, mean = 0, sd = 1, which = c("mu", "sigma"),
 }
 
 ## Hessian
-hcnorm <- function(x, mean = 0, sd = 1, which = c("mu", "sigma"), 
-  left = -Inf, right = Inf) {
+hcnorm <- function(x, mean = 0, sd = 1, left = -Inf, right = Inf, 
+  which = c("mu", "sigma")) {
   input <- data.frame(x = as.numeric(x), mean = as.numeric(mean), sd = as.numeric(sd), 
     left = as.numeric(left), right = as.numeric(right))
   if(!is.character(which))
@@ -74,3 +92,14 @@ hcnorm <- function(x, mean = 0, sd = 1, which = c("mu", "sigma"),
   colnames(hess)[colnames(hess) == "dsigma"] <- "d2sigma"
   hess
 }
+
+
+## Expectation
+ecnorm <- function(mean = 0, sd = 1, left = -Inf, right = Inf) {
+  rmm <- (right-mean)/sd
+  lmm <- (left-mean)/sd
+  pncens <- pnorm(rmm)-pnorm(lmm)
+  pncens*etnorm(mean = mean, sd = sd, left = left, right = right) + 
+    pnorm(lmm)*left^(is.finite(left)) + 
+    pnorm(rmm, lower.tail = FALSE)*right^(is.finite(right))
+}
